function [mse, num_epochs, best_epoch] = create_fit_net(hidden,inputs,targets, testinputs, testtargets)
%CREATE_FIT_NET Creates and trains a fitting neural network.
%
%  NET = CREATE_FIT_NET(INPUTS,TARGETS) takes these arguments:
%    INPUTS - RxQ matrix of Q R-element input samples
%    TARGETS - SxQ matrix of Q S-element associated target samples
%  arranged as columns, and returns these results:
%    NET - The trained neural network
%
%  For example, to solve the Simple Fit dataset problem with this function:
%
%    load simplefit_dataset
%    net = create_fit_net(simplefitInputs,simplefitTargets);
%    simplefitOutputs = sim(net,simplefitInputs);
%
%  To reproduce the results you obtained in NFTOOL:
%
%    net = create_fit_net(cmp0x2Einput,cmp0x2Eoutput);

if hidden==0
    hidden = 1;
end

net = newfit(inputs,targets,hidden);
net.divideParam.trainRatio = 80/100;  % Adjust as desired
net.divideParam.valRatio = 20/100;  % Adjust as desired
net.divideParam.testRatio = 0/100;  % Adjust as desired

% Train and Apply Network
[net,tr] = train(net,inputs,targets);
testoutputs = sim(net,testinputs);

num_epochs = tr.num_epochs;
best_epoch = tr.best_epoch;
%sad racunanje funkcije cilja: mse
error = (testoutputs - testtargets);
error2 = error.*error;
[m,n] = size(error2);
mse = 0;
for i=1:n
   mse = mse+ sum(error2(:,i))/m;
end
mse = mse / n;
% Plot
%plotperf(tr)
%plotfit(net,inputs,targets)
%plotregression(targets,outputs)
